@@ -2,29 +2,30 @@
 fire
 
 # https://github.com/pallets/click combine with fire. Consider
-# https://github.com/ceccopierangiolieugenio/pyTermTk for display_options build TUI
+# https://github.com/ceccopierangiolieugenio/pyTermTk for choose_from_options build TUI
 # https://github.com/chriskiehl/Gooey build commandline interface
 
 """
 
 from machineconfig.scripts.python.helpers.helpers4 import search_for_files_of_interest
-from machineconfig.scripts.python.helpers.helpers4 import convert_kwargs_to_fire_kwargs_str
 from machineconfig.scripts.python.helpers.helpers4 import parse_pyfile
 from machineconfig.scripts.python.helpers.helpers4 import get_import_module_code
-from machineconfig.utils.ve import get_repo_root, get_ve_activate_line, get_ve_path_and_ipython_profile
-from machineconfig.utils.options import display_options, choose_one_option
-from machineconfig.utils.path import match_file_name, sanitize_path
+from machineconfig.utils.ve import get_ve_activate_line, get_ve_path_and_ipython_profile
+from machineconfig.utils.options import choose_from_options
+from machineconfig.utils.path_helper import match_file_name, sanitize_path
 
-from machineconfig.utils.path_reduced import PathExtended as PathExtended
-from machineconfig.utils.io_save import save_toml
-from machineconfig.utils.utils2 import randstr, read_toml
-from machineconfig.scripts.python.fire_jobs_args_helper import get_args, FireJobArgs, extract_kwargs
+from machineconfig.utils.path_extended import PathExtended as PathExtended
+from machineconfig.utils.accessories import get_repo_root, randstr
+from machineconfig.scripts.python.fire_jobs_args_helper import FireJobArgs, extract_kwargs, parse_fire_args_from_context
 import platform
-from typing import Optional
+from typing import Optional, Annotated
+from pathlib import Path
+import tomllib
+import typer
 # import os
 
 
-def route(args: FireJobArgs) -> None:
+def route(args: FireJobArgs, fire_args: str = "") -> None:
     if args.layout:
         from machineconfig.scripts.python.fire_jobs_layout_helper import handle_layout_args
 
@@ -38,20 +39,21 @@ def route(args: FireJobArgs) -> None:
         print(f"🔍 Searching recursively for Python, PowerShell and Shell scripts in directory `{path_obj}`")
         files = search_for_files_of_interest(path_obj)
         print(f"🔍 Got #{len(files)} results.")
-        choice_file = choose_one_option(options=files, fzf=True)
+        choice_file = choose_from_options(multi=False, options=files, fzf=True, msg="Choose one option")
         choice_file = PathExtended(choice_file)
     else:
         choice_file = path_obj
-    repo_root = get_repo_root(str(choice_file))
+    repo_root = get_repo_root(Path(choice_file))
     print(f"💾 Selected file: {choice_file}.\nRepo root: {repo_root}")
     ve_root_from_file, ipy_profile = get_ve_path_and_ipython_profile(choice_file)
     if ipy_profile is None:
         ipy_profile = "default"
-    activate_ve_line = get_ve_activate_line(ve_root=args.ve or ve_root_from_file or "$HOME/code/machineconfig/.venv")
 
     if choice_file.suffix == ".py":
-        kwargs = extract_kwargs(args)
+        kwargs = extract_kwargs(args)  # This now returns empty dict, but kept for compatibility
+        activate_ve_line = get_ve_activate_line(ve_root=args.ve or ve_root_from_file or "$HOME/code/machineconfig/.venv")
     else:
+        activate_ve_line = ""
         kwargs = {}
 
     # =========================  choosing function to run
@@ -59,7 +61,7 @@ def route(args: FireJobArgs) -> None:
     if args.choose_function or args.submit_to_cloud:
         if choice_file.suffix == ".py":
             options, func_args = parse_pyfile(file_path=str(choice_file))
-            choice_function_tmp = display_options(msg="Choose a function to run", options=options, fzf=True, multi=False)
+            choice_function_tmp = choose_from_options(msg="Choose a function to run", options=options, fzf=True, multi=False)
             assert isinstance(choice_function_tmp, str), f"choice_function must be a string. Got {type(choice_function_tmp)}"
             choice_index = options.index(choice_function_tmp)
             choice_function = choice_function_tmp.split(" -- ")[0]
@@ -80,7 +82,7 @@ def route(args: FireJobArgs) -> None:
                 if line.startswith("echo"):
                     continue
                 options.append(line)
-            chosen_lines = display_options(msg="Choose a line to run", options=options, fzf=True, multi=True)
+            chosen_lines = choose_from_options(msg="Choose a line to run", options=options, fzf=True, multi=True)
             choice_file = PathExtended.tmpfile(suffix=".sh")
             choice_file.parent.mkdir(parents=True, exist_ok=True)
             choice_file.write_text("\n".join(chosen_lines), encoding="utf-8")
@@ -91,7 +93,6 @@ def route(args: FireJobArgs) -> None:
     if choice_file.suffix == ".py":
         if args.streamlit:
             import socket
-
             s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
             try:
                 s.connect(("8.8.8.8", 1))
@@ -112,7 +113,7 @@ def route(args: FireJobArgs) -> None:
                     toml_path = toml_path_maybe
             if toml_path is not None:
                 print(f"📄 Reading config.toml @ {toml_path}")
-                config = read_toml(toml_path)
+                config = tomllib.loads(toml_path.read_text(encoding="utf-8"))
                 if "server" in config:
                     if "port" in config["server"]:
                         port = config["server"]["port"]
@@ -120,7 +121,7 @@ def route(args: FireJobArgs) -> None:
                 if repo_root is not None:
                     secrets_template_path = PathExtended.home().joinpath(f"dotfiles/creds/streamlit/{PathExtended(repo_root).name}/{choice_file.name}/secrets.toml")
                     if args.environment != "" and not secrets_path.exists() and secrets_template_path.exists():
-                        secrets_template = read_toml(secrets_template_path)
+                        secrets_template = tomllib.loads(secrets_template_path.read_text(encoding="utf-8"))
                         if args.environment == "ip":
                             host_url = f"http://{local_ip_v4}:{port}/oauth2callback"
                         elif args.environment == "localhost":
@@ -133,7 +134,7 @@ def route(args: FireJobArgs) -> None:
                             secrets_template["auth"]["redirect_uri"] = host_url
                             secrets_template["auth"]["cookie_secret"] = randstr(35)
                             secrets_template["auth"]["auth0"]["redirect_uri"] = host_url
-                            save_toml(obj=secrets_template, path=secrets_path)
+                            # save_toml(obj=secrets_template, path=secrets_path)
                         except Exception as ex:
                             print(ex)
                             raise ex
@@ -215,8 +216,7 @@ except ImportError as _ex:
         # both selected function and kwargs are mentioned in the made up script, therefore no need for fire module.
         command = f"{exe} {choice_file} "
     elif choice_function is not None:
-        kwargs_str = convert_kwargs_to_fire_kwargs_str(kwargs)
-        command = f"{exe} -m fire {choice_file} {choice_function} {kwargs_str}"
+        command = f"{exe} -m fire {choice_file} {choice_function} {fire_args}"
     elif args.streamlit:
         # for .streamlit config to work, it needs to be in the current directory.
         if args.holdDirectory:
@@ -228,8 +228,7 @@ except ImportError as _ex:
         command = rf""" cd /d {choice_file.parent} & {exe} {choice_file.name} """
     else:
         if choice_file.suffix == "":
-            kwargs_raw = " ".join(args.kw) if args.kw is not None else ""
-            command = f"{exe} {choice_file} {kwargs_raw}"
+            command = f"{exe} {choice_file} {fire_args}"
         else:
             # command = f"cd {choice_file.parent}\n{exe} {choice_file.name}\ncd {PathExtended.cwd()}"
             command = f"{exe} {choice_file} "
@@ -323,15 +322,87 @@ python -m machineconfig.cluster.templates.cli_click --file {choice_file} """
     # program_path.parent.mkdir(parents=True, exist_ok=True)
     # program_path.write_text(command, encoding="utf-8")
     import subprocess
+
     subprocess.run(command, shell=True, check=True)
 
 
-def main():
-    args = get_args()
-    route(args)
+def main(
+    ctx: typer.Context,
+    path: Annotated[str, typer.Argument(help="Path to the Python file to run")] = ".",
+    function: Annotated[Optional[str], typer.Argument(help="Function to run")] = None,
+    ve: Annotated[str, typer.Option("--ve", "-v", help="Virtual environment name")] = "",
+    cmd: Annotated[bool, typer.Option("--cmd", "-B", help="Create a cmd fire command to launch the job asynchronously")] = False,
+    interactive: Annotated[bool, typer.Option("--interactive", "-i", help="Whether to run the job interactively using IPython")] = False,
+    debug: Annotated[bool, typer.Option("--debug", "-d", help="Enable debug mode")] = False,
+    choose_function: Annotated[bool, typer.Option("--choose_function", "-c", help="Choose function interactively")] = False,
+    loop: Annotated[bool, typer.Option("--loop", "-l", help="Infinite recursion (runs again after completion/interruption)")] = False,
+    jupyter: Annotated[bool, typer.Option("--jupyter", "-j", help="Open in a jupyter notebook")] = False,
+    submit_to_cloud: Annotated[bool, typer.Option("--submit_to_cloud", "-C", help="Submit to cloud compute")] = False,
+    remote: Annotated[bool, typer.Option("--remote", "-r", help="Launch on a remote machine")] = False,
+    module: Annotated[bool, typer.Option("--module", "-m", help="Launch the main file")] = False,
+    streamlit: Annotated[bool, typer.Option("--streamlit", "-S", help="Run as streamlit app")] = False,
+    environment: Annotated[str, typer.Option("--environment", "-E", help="Choose ip, localhost, hostname or arbitrary url")] = "",
+    holdDirectory: Annotated[bool, typer.Option("--holdDirectory", "-D", help="Hold current directory and avoid cd'ing to the script directory")] = False,
+    PathExport: Annotated[bool, typer.Option("--PathExport", "-P", help="Augment the PYTHONPATH with repo root")] = False,
+    git_pull: Annotated[bool, typer.Option("--git_pull", "-g", help="Start by pulling the git repo")] = False,
+    optimized: Annotated[bool, typer.Option("--optimized", "-O", help="Run the optimized version of the function")] = False,
+    Nprocess: Annotated[int, typer.Option("--Nprocess", "-p", help="Number of processes to use")] = 1,
+    zellij_tab: Annotated[Optional[str], typer.Option("--zellij_tab", "-z", help="Open in a new zellij tab")] = None,
+    watch: Annotated[bool, typer.Option("--watch", "-w", help="Watch the file for changes")] = False,
+    layout: Annotated[bool, typer.Option("--layout", "-L", help="Use layout configuration (Zellij Or WindowsTerminal)")] = False,
+) -> None:
+    """Main function to process fire jobs arguments."""
+    
+    # Get Fire arguments from context
+    fire_args = parse_fire_args_from_context(ctx)
+    
+    args = FireJobArgs(
+        path=path,
+        function=function,
+        ve=ve,
+        cmd=cmd,
+        interactive=interactive,
+        debug=debug,
+        choose_function=choose_function,
+        loop=loop,
+        jupyter=jupyter,
+        submit_to_cloud=submit_to_cloud,
+        remote=remote,
+        module=module,
+        streamlit=streamlit,
+        environment=environment,
+        holdDirectory=holdDirectory,
+        PathExport=PathExport,
+        git_pull=git_pull,
+        optimized=optimized,
+        Nprocess=Nprocess,
+        zellij_tab=zellij_tab,
+        watch=watch,
+        layout=layout,
+    )
+    try:
+        route(args, fire_args)
+    except SystemExit:
+        # Re-raise SystemExit to preserve exit codes and allow clean exits
+        raise
+    except Exception as e:
+        # For other exceptions, print clean error message and exit
+        import sys
+        print(f"❌ Error: {e}", file=sys.stderr)
+        sys.exit(1)
+
+
+def main_from_parser():
+    # from trogon.typer import init_tui
+    # from trogon.typer import init_tui
+    from typer import Typer
+    app = Typer(add_completion=False)
+    app.command(context_settings={"allow_extra_args": True, "allow_interspersed_args": False})(main)
+    # typer.run(main)
+    # init_tui(app)
+    app()
 
 
 if __name__ == "__main__":
     # options, func_args = parse_pyfile(file_path="C:/Users/aalsaf01/code/machineconfig/myresources/crocodile/core.py")
-    args = get_args()
-    route(args)
+    main_from_parser()
