@@ -3,12 +3,12 @@
 import psutil
 from rich.progress import Progress, SpinnerColumn, TextColumn
 from zoneinfo import ZoneInfo
-from machineconfig.utils.options import display_options
+from machineconfig.utils.options import choose_from_options
 from typing import Optional, Any
 from rich.console import Console
 from rich.panel import Panel
 from datetime import datetime, timezone
-from machineconfig.utils.utils2 import pprint
+from machineconfig.utils.accessories import pprint
 
 console = Console()
 
@@ -20,13 +20,10 @@ def get_processes_accessing_file(path: str):
     title = "🔍  SEARCHING FOR PROCESSES ACCESSING FILE"
     console.print(Panel(title, title="[bold blue]Process Info[/bold blue]", border_style="blue"))
     res: dict[int, list[str]] = {}
-    
-    with Progress(
-        SpinnerColumn(),
-        TextColumn("[progress.description]{task.description}"),
-    ) as progress:
+
+    with Progress(SpinnerColumn(), TextColumn("[progress.description]{task.description}")) as progress:
         progress.add_task("🔎 Scanning processes...", total=None)
-        
+
         for proc in psutil.process_iter():
             try:
                 files = proc.open_files()
@@ -35,7 +32,7 @@ def get_processes_accessing_file(path: str):
             tmp = [file.path for file in files if path in file.path]
             if len(tmp) > 0:
                 res[proc.pid] = tmp
-                
+
     # Convert to list of dictionaries for consistent data structure
     result_data = [{"pid": pid, "files": files} for pid, files in res.items()]
     console.print(Panel(f"✅ Found {len(res)} processes accessing the specified file", title="[bold blue]Process Info[/bold blue]", border_style="blue"))
@@ -61,13 +58,10 @@ class ProcessManager:
         title = "📊  INITIALIZING PROCESS MANAGER"
         console.print(Panel(title, title="[bold blue]Process Info[/bold blue]", border_style="blue"))
         process_info = []
-        
-        with Progress(
-            SpinnerColumn(),
-            TextColumn("[progress.description]{task.description}"),
-        ) as progress:
+
+        with Progress(SpinnerColumn(), TextColumn("[progress.description]{task.description}")) as progress:
             progress.add_task("🔍 Reading system processes...", total=None)
-            
+
             for proc in psutil.process_iter():
                 try:
                     mem_usage_mb = proc.memory_info().rss / (1024 * 1024)
@@ -126,7 +120,7 @@ class ProcessManager:
         # Format data as table for display
         formatted_data = self._format_process_table()
         options = formatted_data.split("\n")[1:]  # Skip header
-        res = display_options(options=formatted_data.split("\n"), msg="📋 Select processes to manage:", fzf=True, multi=True)
+        res = choose_from_options(options=formatted_data.split("\n"), msg="📋 Select processes to manage:", fzf=True, multi=True)
         indices = [options.index(val) for val in res]
         selected_processes = [self.data[i] for i in indices]
 
@@ -246,8 +240,10 @@ def get_age(create_time: Any) -> str:
 
 
 def main():
-    from machineconfig.utils.procs import ProcessManager; ProcessManager().choose_and_kill()
+    from machineconfig.utils.procs import ProcessManager
+
+    ProcessManager().choose_and_kill()
 
 
 if __name__ == "__main__":
-    main()
+    pass
